SAFE_GLOBALS = {
    'list': list,
    'dict': dict,
    'set': set,
    'str': str,
    'int': int,
    'float': float,
    'bool': bool,
    'range': range,
    'iter': iter,
    'max': max,
    'min': min,
    'sum': sum,
    'abs': abs
}
